@@ -7,17 +7,19 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/files/register', [
     'io.ox/core/extensions',
     'io.ox/core/capabilities',
     'oxguard/oxguard_core',
     'io.ox/core/folder/api',
+    'io.ox/files/api',
     'oxguard/files/util',
     'io.ox/core/dropzone',
     'oxguard/auth',
     'gettext!oxguard',
     'io.ox/backbone/views/actions/util'
-], function (ext, capabilities, oxguard, folderAPI, util, dropzone, auth_core, gt, actionsUtil) {
+], function (ext, capabilities, oxguard, folderAPI, filesAPI, util, dropzone, auth_core, gt, actionsUtil) {
 
     'use strict';
 
@@ -49,11 +51,12 @@ define('oxguard/files/register', [
 
     //////   Links
     // Add link for add and encrypt local file
-    new actionsUtil.Action('io.ox/files/toolbar/new', {
+    new actionsUtil.Action('io.ox/files/toolbar/upload', {
         index: 110,
         id: 'uploadEncrypt',
-        title: gt('Add and encrypt local file'),
-        ref: 'io.ox/files/actions/uploadEncrypt'
+        title: _.device('smartphone') ? gt('Upload file (encrypted)') : gt('File (encrypted)'),
+        ref: 'io.ox/files/actions/uploadEncrypt',
+        section: 'upload'
     });
 
     ext.point('io.ox/files/toolbar/links').extend({
@@ -164,11 +167,11 @@ define('oxguard/files/register', [
             if (baton.data.selection) {
                 return def.resolve();  // Not handling here
             }
-            var files = baton.data.files;
+            var files = baton.data.fileList;
             if (!files || files.length === 0) {
                 return def.resolve();
             }
-            var file = files[0];
+            var file = (files[0] instanceof filesAPI.Model) ? files[0].toJSON() : files[0];
             if (isOGFile(file)) {
                 auth_core.authorize(file, undefined, true)
                 .then(function (auth) {
@@ -199,21 +202,21 @@ define('oxguard/files/register', [
         }
     });
 
-    ext.point('io.ox/core/viewer/actions/toolbar/popoutstandalone').extend({
-        id: 'popoutstandalone_guardcheck',
-        index: 1,
-        device: '!smartphone',
-        matches: function (baton) {
-            var model = baton.model;
-            return model.get('group') !== 'localFile' && !baton.context.standalone && model.isEncrypted();
-        },
-        action: function (baton) {
-            if (baton.model.isEncrypted()) {
-                actionsUtil.invoke('oxguard/popoutstandalone', baton);
-                baton.preventDefault();
-            }
-        }
-    });
+    // ext.point('io.ox/core/viewer/actions/toolbar/popoutstandalone').extend({
+    //     id: 'popoutstandalone_guardcheck',
+    //     index: 1,
+    //     device: '!smartphone',
+    //     matches: function (baton) {
+    //         var model = baton.model;
+    //         return model.get('group') !== 'localFile' && !baton.context.standalone && model.isEncrypted();
+    //     },
+    //     action: function (baton) {
+    //         if (baton.model.isEncrypted()) {
+    //             actionsUtil.invoke('oxguard/popoutstandalone', baton);
+    //             baton.preventDefault();
+    //         }
+    //     }
+    // });
 
     ext.point('io.ox/core/viewer/toolbar/links/drive').extend({
         id: 'GuardViewerEncrypt',
@@ -252,14 +255,33 @@ define('oxguard/files/register', [
 
     // Versions
 
-    ext.point('io.ox/files/versions/links/inline').extend({
+    ext.point('io.ox/files/versions/links/inline/current').extend({
         id: 'GuardView',
         index: 90,
         title: gt('View this version'),
+        section: 'view',
         ref: 'oxguard/versionView'
     });
 
-    ext.point('io.ox/files/versions/links/inline').extend({
+    ext.point('io.ox/files/versions/links/inline/older').extend({
+        id: 'GuardView',
+        index: 90,
+        title: gt('View this version'),
+        section: 'view',
+        ref: 'oxguard/versionView'
+    });
+
+
+    // download current version
+    ext.point('io.ox/files/versions/links/inline/current').extend({
+        id: 'GuardDownload',
+        index: 200,
+        title: gt('Download decrypted'),
+        ref: 'oxguard/download'
+    });
+
+    // download older versions
+    ext.point('io.ox/files/versions/links/inline/older').extend({
         id: 'GuardDownload',
         index: 200,
         title: gt('Download decrypted'),
@@ -283,9 +305,23 @@ define('oxguard/files/register', [
         return model ? folderAPI.is('trash', model.toJSON()) : false;
     }
 
+    function isCurrentVersion(baton) {
+        // folder tree folder, always current version
+        if (!baton.collection.has('some')) return true;
+        // drive folder, always current version
+        if (baton.collection.has('folders')) return true;
+        // single selection
+        if (baton.collection.has('one') && baton.first().current_version !== false) return true;
+        // multi selection
+        if (baton.collection.has('multiple') && baton.array().every(function (file) { return file.current_version !== false; })) return true;
+        // default
+        return false;
+    }
+
     // Upload new encrypted file
     new actionsUtil.Action('io.ox/files/actions/uploadEncrypt', {
         capabilities: 'guard-drive && !guest',
+        folder: 'create',
         matches: function (baton) {
             if (_(['14', '15']).contains(baton.folder_id)) return false;
             if (isTrash(baton)) return false;
@@ -315,7 +351,12 @@ define('oxguard/files/register', [
                     file.params = {};
                 }
             });
-            actionsUtil.invoke('io.ox/files/actions/download', baton);
+
+            if (isCurrentVersion(baton)) {
+                actionsUtil.invoke('io.ox/files/actions/download', baton);
+            } else {
+                actionsUtil.invoke('io.ox/files/actions/downloadversion', baton);
+            }
 
         }
     });
@@ -359,25 +400,25 @@ define('oxguard/files/register', [
     });
 
     // Replacement popout for Guard
-    new actionsUtil.Action('oxguard/popoutstandalone', {
-        collection: 'one',
-        id: 'guardPopout',
-        matches: function (baton) {
-            var currentApp = ox.ui.App.getCurrentApp().getName();
-            // detail is the target of popoutstandalone, no support for mail attachments
-            return (currentApp !== 'io.ox/files/detail' && baton.model.isEncrypted());
-        },
-        action: function (e) {
-            ox.launch('io.ox/files/detail/main').done(function () {
-                var node = this.getWindowNode();
-                this.setTitle(e.data.filename);
-                var app = this;
-                ox.load(['io.ox/mail/actions/viewer']).done(function (action) {
-                    action({ files: [e.data], app: app, container: node, standalone: true });
-                });
-            });
-        }
-    });
+    // new actionsUtil.Action('oxguard/popoutstandalone', {
+    //     collection: 'one',
+    //     id: 'guardPopout',
+    //     matches: function (baton) {
+    //         var currentApp = ox.ui.App.getCurrentApp().getName();
+    //         // detail is the target of popoutstandalone, no support for mail attachments
+    //         return (currentApp !== 'io.ox/files/detail' && baton.model.isEncrypted());
+    //     },
+    //     action: function (e) {
+    //         ox.launch('io.ox/files/detail/main').done(function () {
+    //             var node = this.getWindowNode();
+    //             this.setTitle(e.data.filename);
+    //             var app = this;
+    //             ox.load(['io.ox/mail/actions/viewer']).done(function (action) {
+    //                 action({ files: [e.data], app: app, container: node, standalone: true });
+    //             });
+    //         });
+    //     }
+    // });
 
     // View link within versions
     new actionsUtil.Action('oxguard/versionView', {
@@ -394,6 +435,7 @@ define('oxguard/files/register', [
         capabilities: 'guard-drive && webmail',
         collection: 'some',
         matches: function (baton) {
+            if (baton.isViewer && !isCurrentVersion(baton)) return false;
             //all files must be encrypted
             var toCheck = baton.models === null ? baton.model : baton.models;
             return util.hasEncrypted(toCheck) && util.isNotAttachment(toCheck);
@@ -413,10 +455,11 @@ define('oxguard/files/register', [
     }
 
     new actionsUtil.Action('oxguard/remencrypt', {
-        capabilities: 'guard-drive',
+        capabilities: 'guard-drive && !guest',
         collection: '!folders',
         matches: function (baton) {
             //all files must be encrypted
+            if (baton.isViewer && !isCurrentVersion(baton)) return false;
             if (!anyOGFiles(baton.data)) return false;
             if (baton.app) {
                 return baton.app.folder.getData().then(function (data) {
@@ -531,6 +574,7 @@ define('oxguard/files/register', [
             var list = baton.array();
             auth_core.authorize(list).then(function (auth) {
                 list.map(function (file) {
+                    file.originalFilename = file.filename;
                     file.filename = (file.filename ? file.filename.replace('.pgp', '') : '');
                     file.params = {
                         'cryptoAction': 'Decrypt',
@@ -539,7 +583,14 @@ define('oxguard/files/register', [
                     };
                     file.cache = false;
                 });
-                actionsUtil.invoke('io.ox/files/actions/downloadversion', baton);
+                actionsUtil.invoke('io.ox/files/actions/downloadversion', baton)
+                .then(function () { // Guard-221, subsequent calls to download returns decrypted file
+                    list.map(function (file) {
+                        file.filename = file.originalFilename;
+                        file.params.cryptoAction = undefined;
+                        file.params.cryptoAuth = undefined;
+                    });
+                });
                 metrics('guard', 'decrypt & download');
             });
         }
@@ -552,11 +603,14 @@ define('oxguard/files/register', [
         id: 'guardview',
         index: 1,
         collection: 'some && items',
-        // matches: hasAnyEncryptedFile,
+
         matches: function (baton) {
-            if (baton.isViewer) return false;
+            // don't open a new viewer instance within the viewer
+            if (baton.isViewer) { return false; }
+
             return hasAnyEncryptedFileInSelection(baton);
         },
+
         action: function (baton) {
             viewFile(baton);
         }
@@ -631,7 +685,7 @@ define('oxguard/files/register', [
     ext.point('io.ox/files/dropzone').extend({
         id: 'dragDrop',
         getDropZones: function (baton) {
-            if (!capabilities.has('guard-drive')) return;
+            if (!capabilities.has('guard-drive') || capabilities.has('guest')) return;
             var app = baton.app,
                 zone2 = new dropzone.Inplace({
                     caption: gt('Drop files here to encrypt')
@@ -684,9 +738,10 @@ define('oxguard/files/register', [
     }
 
     new actionsUtil.Action('oxguard/encrypt', {
-        capabilities: 'guard-drive',
+        capabilities: 'guard-drive && !guest',
         collection: 'some',
         matches: function (baton) {
+            if (baton.isViewer && !isCurrentVersion(baton)) return false;
             //all files must be unencrypted
             if (baton.app) {
                 return baton.app.folder.getData().then(function (data) {
