@@ -16,6 +16,7 @@ define('oxguard/mail/options_new', [
     'gettext!oxguard',
     'less!oxguard/mail/style'
 ], function (core, util, coreUtil, settings, gt) {
+
     'use strict';
 
     var lockclass = 'icon-lock icon-2x fa fa-lock fa-2x oxguard_lock';
@@ -126,8 +127,8 @@ define('oxguard/mail/options_new', [
         }
 
         createlock(baton);
-
-        if (baton.config.get('newmail') === true && coreUtil.hasGuardMailCapability()) {  // New email doesn't have recips yet.  Check to see if there are defaults
+        // Guard bug GUARD-200, deleted user still has defaults applied.  Verify configured before applying
+        if (baton.config.get('newmail') === true && coreUtil.hasGuardMailCapability() && coreUtil.isGuardConfigured()) {  // New email doesn't have recips yet.  Check to see if there are defaults
             // If default is to use guard, go ahead and lock
             if (settings.get('defaultEncrypted')) {
                 securityModel.set('encrypt', true);
