@@ -9,24 +9,24 @@ define('oxguard/mail/register_compose', [
     'oxguard/mail/keymanager',
     'settings!oxguard',
     'oxguard/mail/security_model',
+    'io.ox/mail/compose/api',
     'less!oxguard/mail/style'
-], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings, SecurityModel) {
+], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings, SecurityModel, composeAPI) {
+
     'use strict';
 
-    // Setup of compose
+    // Mobile only
 
     ext.point('io.ox/mail/compose/fields').extend({
-        id: 'lock',
+        id: 'lock-mobile',
         index: 250,
         draw: function (baton) {
-            if (!util.hasCryptoCapability()) {
-                // TODO check for encr reply
-                return;
-            }
+            if (_.device('!smartphone')) return;
+            if (!util.hasCryptoCapability()) return;
             var node = this;
             var securityModel = new SecurityModel(baton.model.get('security'), baton.model);
             baton.view.securityModel = securityModel;
-            var view = new ToggleEncryption.View({
+            var view = new ToggleEncryption.ViewMobile({
                 model: securityModel
             }, baton.model);
             view.noLinkMail(baton.view);
@@ -37,9 +37,133 @@ define('oxguard/mail/register_compose', [
         }
     });
 
-    function setupCompose(baton) {
+    ext.point('io.ox/mail/compose/menu-mobile').replace({
+        id: 'security',
+        index: 100,
+        draw: function (baton) {
+            var node = this;
+            if (_.device('!smartphone')) return;
+            drawDropDownMobile(baton, $(node));
+        }
+    });
 
-        // Check the options for the page.  Lock icon settings, etc
+    // Desktop only
+    ext.point('io.ox/mail/compose/fields').extend({
+        id: 'info-and-options',
+        index: 900,
+        draw: function (baton) {
+            if (_.device('smartphone')) return;
+            if (!util.hasCryptoCapability()) return;
+
+            // row
+            var composeUtil = require('io.ox/mail/compose/util'),
+                node = composeUtil.infoLine({
+                    icon: 'fa-lock',
+                    text: gt('This email will be encrypted.')
+                }).addClass('stripes-green encrypted');
+            this.append(node);
+
+            // toggle
+            update();
+            baton.view.securityModel.on('change:encrypt', update);
+            function update() {
+                node.toggleClass('hidden', !baton.view.securityModel.get('encrypt'));
+            }
+
+            // dropdown
+            if (!window.oxguarddata || !window.oxguarddata.settings || !window.oxguarddata.settings.oxguard) return;
+            var dropdown = new Dropdown({
+                model: baton.view.securityModel,
+                label: gt('Options'),
+                caret: true
+            })
+            .header(gt('Security'))
+            .option('PGPSignature', true, gt('Sign email'))
+            .option('PubKey', true, gt('Attach my public key'));
+
+            if (settings.get('advanced')) {
+                dropdown
+                //#. Format of the email, HTML or Plaintext
+                .header(gt('PGP Format'))
+                .option('PGPFormat', 'mime', gt('Mime'))
+                .option('PGPFormat', 'inline', gt('Inline'));
+            }
+
+            //  Help icon
+            dropdown.render().$el
+                .addClass('security-options')
+                .find('ul').prepend(
+                    new HelpView({
+                        base: 'help',
+                        iconClass: 'guardhelp fa-question-circle fa',
+                        href: 'ox.appsuite.user.sect.guard.email.send.html',
+                        tabindex: '-1'
+                    }).render().$el.addClass('guard-help-icon')
+                );
+
+            node.append(dropdown.$el);
+        }
+    });
+
+    ext.point('io.ox/mail/compose/composetoolbar').extend({
+        id: 'lock',
+        index: 400,
+        draw: function (baton) {
+            if (_.device('smartphone')) return;
+            // TODO check for encr reply
+            if (!util.hasCryptoCapability()) return;
+
+            var container = $('<li role="presentation">');
+            var securityModel = new SecurityModel(baton.model.get('security'), baton.model),
+                view = new ToggleEncryption.View({
+                    tagName: 'a',
+                    model: securityModel,
+                    mailModel: baton.model
+                });
+
+            baton.view.securityModel = securityModel;
+            baton.view.toggleEncryption = view;
+            view.noLinkMail(baton.view);
+
+            this.append(
+                container.append(view.render().$el)
+            );
+
+            setupCompose(baton);
+        }
+    });
+
+    ext.point('io.ox/mail/compose/menuoptions').extend({
+        id: 'guard-options',
+        index: 400,
+        draw: function (baton) {
+            if (_.device('smartphone')) return;
+            if (!util.hasCryptoCapability()) return;
+
+            var intermediateModel = this.data('view').model,
+                securityModel = baton.view.securityModel;
+
+            // sync updates of intermediateModel (dropdown) and securityModel
+            ['PGPSignature', 'PubKey'].forEach(function (key) {
+                intermediateModel.set(key, securityModel.get(key));
+                intermediateModel.on('change:' + key, function name() {
+                    securityModel.set(key, intermediateModel.get(key));
+                });
+                securityModel.on('change:' + key, function name() {
+                    intermediateModel.set(key, securityModel.get(key));
+                });
+            });
+
+            this.data('view')
+                .divider()
+                .header(gt('Security'))
+                .option('PGPSignature', true, gt('Sign email'))
+                .option('PubKey', true, gt('Attach my public key'));
+        }
+    });
+
+    function setupCompose(baton) {
+        // Check the options for the page. Lock icon settings, etc
         require(['oxguard/mail/options_new'], function (options) {
             options.createOptions(baton);
         });
@@ -68,27 +192,37 @@ define('oxguard/mail/register_compose', [
         }
     });
 
-    ext.point('io.ox/mail/compose/menu').replace({
-        id: 'security',
-        index: 100,
-        draw: function (baton) {
-            var node = this;
-            drawDropDown(baton, $(node));
-        }
-    });
-
     // Token and key handling
 
     ext.point('io.ox/mail/compose/createtoken').extend({
         id: 'guardToken',
         action: function (baton) {
             if (baton.view.securityModel.get('encrypt') === true) {
-                var email = baton.event.attrs.model.get('token').value;
                 var target = $(baton.event.relatedTarget);
+                var email = baton.event.attrs.model.get('token').value;
+                // OK, check the keys
                 keyman.checkRecips(email, baton)
                 .done(function (keyResults) {
                     core.drawKeyIcons(keyResults[email], target);
                 });
+                // Handle tooltip with keyboard nav
+                target.on('focus', function () {
+                    if (target.hasClass('grabbed')) {
+                        // Don't show if grabbed
+                        target.find('.key_tooltip').tooltip('hide');
+                    } else {
+                        target.find('.key_tooltip').tooltip('show');
+                    }
+                });
+                target.on('blur', function () {
+                    target.find('.key_tooltip').tooltip('hide');
+                });
+                // If moving token around, hide tooltip
+                target.on('keyup', function (e) {
+                    if (e.which === 32) {
+                        target.find('.key_tooltip').tooltip('hide');
+                    }
+                });
             }
         }
     });
@@ -204,14 +338,16 @@ define('oxguard/mail/register_compose', [
         {
             // Check for authentication errors
             id: 'checkAuthErrors',
-            index: 100,
+            index: 2900,
             after: 'send',
             perform: function (baton) {
-                if (baton.result && containsError(baton.result.code, baton.result.error)) {
+                if (baton.error && containsError(baton.errorCode, baton.error)) {
                     handleFail(baton);
                     handleReauth(gt('Please re-enter your %s password before sending.', window.oxguarddata.productName), baton)
                     .done(function () {
-                        baton.view.send();
+                        updateAuth(baton.model).then(function () {
+                            baton.view.send();
+                        });
                     });
                     return new $.Deferred().reject();
                 }
@@ -219,25 +355,76 @@ define('oxguard/mail/register_compose', [
         }
     );
 
+    function updateAuth(model) {
+        var security = model.get('security');
+        security.authToken = security.authentication;
+        delete security.authentication;
+        return composeAPI.space.update(model.get('id'), { security: security });
+    }
+
     // Save extension points
 
     ext.point('io.ox/mail/compose/actions/save').extend({
         id: 'checkAuthErrors',
-        index: 1100,
+        index: 1050,
         perform: function (baton) {
-            if (baton.result && containsError(baton.result.code, baton.result.error)) {
+            if (baton.error && containsError(baton.errorCode, baton.error)) {
                 handleFail(baton);
                 handleReauth(gt('Please re-enter your %s password before saving.', window.oxguarddata.productName), baton)
                 .done(function () {
-                    baton.view.saveDraft();
+                    updateAuth(baton.model);
                 });
+                baton.stopPropagation();
                 return new $.Deferred().reject();
             }
         }
     });
 
+    // GET response event listener
+    ext.point('io.ox/mail/compose/actions/get/error').extend({
+        index: 100,
+        id: 'guardAuthError',
+        handler: function (baton) {
+            if (baton.result && containsError(baton.result.code, baton.result.error)) {
+                baton.handled = $.Deferred();
+                return handleReauth(gt('Please enter your %s password to edit this encrypted draft.', window.oxguarddata.productName), baton)
+                .then(function () {
+                    // TODO: this needs proper converters and serializers/deserializers for compose model <=> guard model <=> JSON
+                    var security = baton.model.get('security');
+                    security.authToken = security.authentication;
+                    delete security.authentication;
+                    return composeAPI.space.update(baton.model.get('id'), { security: security });
+                }).then(function () {
+                    baton.handled.resolve(composeAPI.space.get(baton.model.get('id')));
+                }).catch(function (error) {
+                    baton.handled.reject(error);
+                });
+            }
+        }
+    });
+
     var reauthorizing = false;
 
+    ext.point('io.ox/mail/compose/boot').extend({
+        index: 'last',
+        id: 'guardAuthSaveError',
+        perform: function (baton) {
+            baton.model.on('fail:save', function (e) {
+                if (e.error && e.code) {
+                    if (containsError(e.code, e.error)) {
+                        var model = this;
+                        handleReauth(gt('Please re-enter your %s password before saving.', window.oxguarddata.productName), baton)
+                        .done(function () {
+                            updateAuth(model).then(function () {
+                                model.save();
+                            });
+                        });
+                    }
+                }
+            });
+        }
+    });
+
     ext.point('io.ox/mail/compose/autosave/error').extend({
         index: 1,
         id: 'guardAuthError',
@@ -275,7 +462,7 @@ define('oxguard/mail/register_compose', [
     // Functions
 
     // Drawing dropdown options for security
-    function drawDropDown(baton, node) {
+    function drawDropDownMobile(baton, node) {
         if (window.oxguarddata && window.oxguarddata.settings) {
             if (window.oxguarddata.settings.oxguard) {
                 var dropdown = new Dropdown({ model: baton.view.securityModel, label: gt('Security'), caret: true });
@@ -299,20 +486,8 @@ define('oxguard/mail/register_compose', [
                     .header(gt('Keys'))
                     .option('PubKey', true, gt('Attach my key'));
                 }
-                var dropdownDiv = dropdown.render().$el.addClass('text-left');
-                if (_.device('small')) {
-                    node.addClass('security-mobile');
-                } else {
-                    //  Help icon
-                    dropdownDiv.find('ul').prepend(new HelpView({
-                        base: 'help',
-                        iconClass: 'guardhelp fa-question-circle fa',
-                        href: 'ox.appsuite.user.sect.guard.email.send.html',
-                        tabindex: '-1'
-                    }).render().$el.css('float', 'right').css('margin-right', '10px'));
-                    dropdownDiv.css('padding-left', '20px').addClass('security-options');
-                }
-                node.append(dropdownDiv);
+                node.addClass('security-mobile')
+                    .append(dropdown.render().$el.addClass('text-left'));
             }
         }
     }
@@ -405,9 +580,20 @@ define('oxguard/mail/register_compose', [
                 baton.stopPropagation();
                 def.resolve();
             })
-            .fail(function () {
+            .fail(function (data, e) {
+                // return a ox error object (fallback build one)
+                var error = _.extend({ code: 'unknown', error: gt('An error occurred. Please try again.') }, e || {});
+
+                // adjust error message to be less technical
+                if (data === 'cancel') _.extend(error, { code: 'GRD-UI-0001', error: gt('Authorization failed as password prompt was closed by user') });
+                if (error.code === 'GRD-MW-0003') error.message = gt('Bad password');
+                if (error.code === 'GRD-MW-0005') error.message = gt('Account Locked out');
+
+                // flag error objects that (temporary) breaks access to composition spaces
+                if (/^(GRD-UI-0001|GRD-MW-0003|GRD-MW-0005)$/.test(error.code)) error.critical = true;
+
                 baton.stopPropagation();
-                def.reject(true);
+                def.reject(error);
             });
         });
         return def;
