@@ -7,6 +7,7 @@
  *
  * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/register', [
     'io.ox/core/extensions',
     'gettext!oxguard',
@@ -14,6 +15,7 @@ define('oxguard/register', [
     'io.ox/core/capabilities',
     'less!oxguard/style'
 ], function (ext, gt, settings, capabilities) {
+
     'use strict';
 
     var productName = ox.serverConfig['guard.productName'] === undefined ? settings.get('productName') : ox.serverConfig['guard.productName'];
@@ -152,9 +154,9 @@ define('oxguard/register', [
         return def;
     }
 
-    ext.point('io.ox/core/appcontrol/right/dropdown').extend({
+    ext.point('io.ox/core/appcontrol/right/help').extend({
         id: 'guard-guided-tour',
-        index: 260,
+        index: 290,
         extend: function () {
             if (_.device('small')) return;
             if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
@@ -170,9 +172,9 @@ define('oxguard/register', [
         }
     });
 
-    ext.point('io.ox/core/appcontrol/right/dropdown/signouts').extend({
+    ext.point('io.ox/core/appcontrol/right/account/signouts').extend({
         id: 'logoutOG',
-        index: 10,
+        index: 50,
         extend: function () {
             this.link('logoutOG', gt('Sign out %s', window.oxguarddata.productName), function (e) {
                 e.preventDefault();
