@@ -88,6 +88,11 @@ define('oxguard/settings/views/resetPasswordView', [
                 $('.og_wait').remove();
                 core.removeAuth();
                 require(['io.ox/core/notifications'], function (notify) {
+                    if (data.error) {
+                        notify.yell('error', gt('Unable to reset your password'));
+                        def.reject();
+                        return;
+                    }
                     if (data.indexOf('primary') >= 0) {
                         notify.yell('success', gt('A new password has been sent to your email address.'));
                         window.oxguarddata.passcode = 'Password Needed';
