@@ -72,7 +72,7 @@ define('oxguard/settings/views/revokePrivateView', [
                 if (e && e.length > 1) yell('error', e);
             });
         })
-        .addButton()
+        .addCloseButton()
         .open();
     }
 
