@@ -1,3 +1,14 @@
+/**
+ * All content on this website (including text, images, source
+ * code and any other original works), unless otherwise noted,
+ * is licensed under a Creative Commons License.
+ *
+ * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
+ * Copyright (C) 2016-2020 OX Software GmbH
+ * Author Greg Hill <greg.hill@open-xchange.com>
+ */
+
 define('oxguard/tour/main', [
     'io.ox/core/tk/wizard',
     'io.ox/core/tk/hotspot',
@@ -10,6 +21,7 @@ define('oxguard/tour/main', [
     'gettext!oxguard/tour',
     'less!oxguard/tour/style'
 ], function (Tour, hotspot, core, util, capabilities, HelpView, keys, settings, gt) {
+
     'use strict';
 
     function writeMail() {
@@ -43,6 +55,7 @@ define('oxguard/tour/main', [
             return;
         }
 
+        var def = $.Deferred();
         var tour = new Tour(),
             composeApp;
         var driveText = '';
@@ -72,8 +85,10 @@ define('oxguard/tour/main', [
                         //HACK: can not detect that mail compose window is rendered
                         composeApp.view.$el.addClass('og-ready');
                         window.setTimeout(function () {
+                            composeApp.config.set('autoDismiss', true);
+                            composeApp.view.securityModel.set('tour', true);
                             hotspot.add('.toggle-encryption', { 'top': 14, 'left': 14 });
-                            composeApp.view.$el.find('.toggle-encryption .fa').click();
+                            composeApp.view.$el.closest('.io-ox-mail-compose-window').find('.toggle-encryption .fa').click();
                         }, 500);
                     });
                     ox.registry.call('mail-compose', 'open').done(function (e) {
@@ -91,6 +106,7 @@ define('oxguard/tour/main', [
                 composeApp.view.dirty(false);
                 composeApp.quit();
             }
+            def.resolve();
         });
 
         tour
@@ -208,7 +224,7 @@ define('oxguard/tour/main', [
                         window.setTimeout(function () {
                             $('.classic-toolbar [data-action=more] ~ ul').css('display', 'block');
                             hotspot.add('a[data-action="oxguard/encrypt"]', { 'top': 13, 'left': 10 });
-                        }, 500);
+                        }, 1000);
                     } else {
                         hotspot.add('.dropdown.more-dropdown', { 'top': 13, 'left': 10 });
                     }
@@ -220,22 +236,24 @@ define('oxguard/tour/main', [
             .end();
             driveText = $('<p>').append($('<a href="#">').click(openFiles).text(gt.pgettext('tour', 'Encrypt your sensitive files in Drive')));
         }
+        if (location.href.indexOf('office?app') === -1) {   // We only show restarting guided tours in main tab
+            tour
+            .step()
+                .title(gt.pgettext('tour', 'Restart Guided Tour'))
+                .content(gt.pgettext('tour', '<em>Hint:</em> you can start guided tours, any time you need them, from the system menu.'))
+                .hotspot('[data-name="GuardTour"]', { 'top': 13, 'left': 10 })
+                .waitFor('a[data-name="GuardTour"]')
+                .on('wait', function () {
+                    $('#io-ox-topbar-help-dropdown-icon').find('.dropdown-toggle').click();
+                })
+                .on('next', function () {
+                    if ($('a[data-name="GuardTour"]').css('display') === 'block') {
+                        $('#io-ox-topbar-help-dropdown-icon').find('.dropdown-toggle').click();
+                    }
+                })
+                .end();
+        }
         tour
-        .step()
-            .title(gt.pgettext('tour', 'Restart Guided Tour'))
-            .content(gt.pgettext('tour', '<em>Hint:</em> you can start guided tours, any time you need them, from the system menu.'))
-            .hotspot('[data-name="GuardTour"]', { 'top': 13, 'left': 10 })
-            .referTo('#topbar-settings-dropdown')
-            .waitFor('#topbar-settings-dropdown')
-            .on('wait', function () {
-                $('#io-ox-topbar-dropdown-icon').find('.dropdown-toggle').click();
-            })
-            .on('next', function () {
-                if ($('#topbar-settings-dropdown').css('display') === 'block') {
-                    $('#io-ox-topbar-dropdown-icon').find('.dropdown-toggle').click();
-                }
-            })
-            .end()
         .step()
             .title(gt.pgettext('tour', 'Guided Tour completed'))
             .content($('<div>').append(
@@ -256,6 +274,7 @@ define('oxguard/tour/main', [
             ))
             .end()
         .start();
+        return def;
     });
 
     Tour.registry.add({
@@ -280,10 +299,12 @@ define('oxguard/tour/main', [
             });
 
         tour.once('stop', function () {
-            if (model.get('sent') === false) {
-                def.reject('cancel');
-            } else {
-                def.resolve('OK');
+            if (!model.get('pending')) { // awaiting some other promise
+                if (model.get('sent') === false) {
+                    def.reject('cancel');
+                } else {
+                    def.resolve('OK');
+                }
             }
 
             view.remove();
@@ -343,8 +364,9 @@ define('oxguard/tour/main', [
                 $('<p>').text(gt.format(gt.pgettext('tour', 'Congratulations, you have successfully setup %s'), window.oxguarddata.productName)),
                 $('<p>').text(gt.format(gt.pgettext('tour', 'Now you can learn more about how to use %s by following the links below:'), window.oxguarddata.productName)),
                 $('<p>').append($('<a id="startTourLink" href="#">').click(function () {
+                    model.set('pending', true);
                     $('.wizard-step .btn-primary').click();
-                    Tour.registry.run('default/oxguard');
+                    Tour.registry.get('default/oxguard').get('run')().then(def.resolve, def.resolve);
                     //#. %s product name
                 }).text(gt('Guided tour for %s', window.oxguarddata.productName))),
                 $('<p>').append(new HelpView({
