@@ -8,8 +8,9 @@
  * Copyright (C) 2016-2020 OX Software GmbH
  * Author Greg Hill <greg.hill@open-xchange.com>
  */
-define('pgp_local/storage', [
-], function () {
+
+define('pgp_local/storage', [], function () {
+
     'use strict';
 
     var indexedDB = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
