@@ -41,7 +41,11 @@ module.exports.config = {
             filestoreId: process.env.FILESTORE_ID || 6,
             smtpServer: process.env.SMTP_SERVER || 'localhost',
             imapServer: process.env.IMAP_SERVER || 'localhost',
-            newContext: parseInt(process.env.CONTEXT_ID, 10) + 1
+            newContext: parseInt(process.env.CONTEXT_ID, 10) + 1,
+            admin: {
+                login: process.env.PROVISIONING_USER || 'oxadminmaster',
+                password: process.env.PROVISIONING_PASSWORD || 'secret'
+            }
         },
         GuardHelper: {
             require: './e2e/helper.js'
@@ -144,7 +148,7 @@ module.exports.config = {
             helper.executeSoapRequest('OXContextService', 'delete', {
                 ctx: { id: this.ctxdata.id },
                 auth: auth || this.auth
-            });
+            }).catch(e => console.log(e));
         };
         if (defaultContext.id !== 10) defaultContext.remove();
         //HACK: defer killing selenium, because it's still needed for a few ms
