@@ -16,10 +16,10 @@
  */
 
 
-module.exports  = function (userIndex) {
-    this.waitForVisible('input[name="newogpassword"]');
-    this.insertCryptPassword('input[name="newogpassword"]', userIndex);
+module.exports  = function (userdata) {
+    this.waitForVisible('#newogpassword');
+    this.insertCryptPassword('#newogpassword', userdata);
     this.waitForVisible('.oxguard_hint_warn');
-    this.insertCryptPassword('input[name="newogpassword2"]', userIndex);
+    this.insertCryptPassword('#newogpassword2', userdata);
     this.click('.btn[data-action="okpass"]');
 }
\ No newline at end of file
