@@ -16,7 +16,9 @@
 
 module.exports  = function (userdata, subject, data, attachment, options) {
 
-        options = options || {};
+       options = options || {};
+
+       var optionsDropdown = locate({ css: '[data-extension-id="composetoolbar-menu"] a[aria-label="Options"]' }).as('Options dropdown');
 
        // Open compose
        this.wait(2);
@@ -24,43 +26,46 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        this.waitForVisible('.window-blocker.io-ox-busy');
        this.waitForInvisible('.window-blocker.io-ox-busy');
        this.waitForVisible('.io-ox-mail-compose textarea.plain-text,.io-ox-mail-compose .contenteditable-editor');
-   
+
        // Mark as secure unless specified as non-encrypted
        if (!options.unencrypted) {
-        this.click('Security');
-        this.waitForVisible('.dropdown.open a[data-name="encrypt"]');
-        this.click('Encrypt');
-        this.waitForVisible('.fa.fa-2x.encrypted');
+          this.seeElement('.io-ox-mail-compose-window .toggle-encryption');
+          this.click('.io-ox-mail-compose-window .toggle-encryption');
+          this.waitForVisible('#ogPassword');
+          this.fillField('#ogPassword', userdata.password);
+          this.click('.btn[data-action="ok"]');
+          this.waitForVisible('.fa.fa-2x.encrypted');
        }
 
        if (options.attachKey) {
-          this.click('Security');
-          this.waitForVisible('.dropdown.open a[data-name="PubKey"]');
-          this.click('Attach my key');
+          this.click(optionsDropdown);
+          this.waitForText('Attach my public key', 10, '.dropdown.open .dropdown-menu');
+          this.click('Attach my public key', '.dropdown.open .dropdown-menu');
+          this.waitForElement('.file[title="public.asc"]');
        }
 
        if (options.sign) {
-        this.click('Security');
-        this.waitForVisible('.dropdown.open a[data-name="PGPSignature"]');
-        this.click('Sign');
+        this.click(optionsDropdown);
+        this.waitForText('Sign email', 10, '.dropdown.open .dropdown-menu');
+        this.click('Sign email', '.dropdown.open .dropdown-menu');
        }
-   
+
        // Verify HTML
-       this.click('Options');
+       this.click(optionsDropdown);
        this.click('HTML');
        this.waitForVisible('.io-ox-mail-compose .editor .mce-panel');
 
 
        if (options.inline) {
         this.wait(1);
-        this.click('Security');
+        this.click('Options');
         this.waitForVisible('.dropdown.open a[data-name="PGPFormat"]');
         this.click('.dropdown.open a[data-value="inline"]');
         this.waitForVisible('.btn[data-action="okx"]');
         this.click('.btn[data-action="okx"]');
         this.waitForInvisible('.modal-backdrop');
        }
-   
+
        // Insert test data
        this.fillField('.io-ox-mail-compose div[data-extension-id="to"] input.tt-input', userdata.email1);
        this.fillField('.io-ox-mail-compose [name="subject"]', subject);
@@ -76,18 +81,15 @@ module.exports  = function (userdata, subject, data, attachment, options) {
 
        // Attachments if any
        if (attachment) {
-            this.attachFile('.composetoolbar input[type="file"]', attachment);  
-            this.wait(2); 
+            this.attachFile('.composetoolbar input[type="file"]', attachment);
+            this.wait(2);
        }
-   
+
        // Verify key is next to recipient names
        if (!options.unencrypted) {
             this.waitForVisible('i.fa.fa-key.oxguard_token.key_tooltip.trusted_key');
-            // Send
-            this.click('Send Encrypted');
-       } else {
-           this.click('Send');
        }
+       this.click('Send');
 
        if (options.sign) {
            this.waitForVisible('#ogPassword');
@@ -96,5 +98,5 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        }
        this.waitForVisible('.io-ox-mail-window .leftside');
        I.waitForInvisible('.mail-progress', attachment ? 60 : 10);
-   
-};
\ No newline at end of file
+
+};
