@@ -15,6 +15,7 @@
  */
 
 module.exports  = function (userdata, subject, data, pin) {
+       var optionsDropdown = locate({ css: '[data-extension-id="composetoolbar-menu"] a[aria-label="Options"]' }).as('Options dropdown');
 
        // Open compose
        this.wait(2);
@@ -22,18 +23,19 @@ module.exports  = function (userdata, subject, data, pin) {
        this.waitForVisible('.window-blocker.io-ox-busy');
        this.waitForInvisible('.window-blocker.io-ox-busy');
        this.waitForVisible('.io-ox-mail-compose textarea.plain-text,.io-ox-mail-compose .contenteditable-editor');
-   
+
        // Mark as secure
-       this.click('Security');
-       this.waitForVisible('.dropdown.open a[data-name="encrypt"]');
-       this.click('Encrypt');
+       this.click('.toggle-encryption');
+       this.waitForVisible('#ogPassword');
+        this.fillField('#ogPassword', userdata.password);
+        this.click('.btn[data-action="ok"]');
        this.waitForVisible('.fa.fa-2x.encrypted');
-   
+
        // Verify HTML
-       this.click('Options');
+       this.click(optionsDropdown);
        this.click('HTML');
        this.waitForVisible('.io-ox-mail-compose .editor .mce-panel');
-   
+
        // Insert test data
        this.fillField('.io-ox-mail-compose div[data-extension-id="to"] input.tt-input', userdata.email1);
        this.fillField('.io-ox-mail-compose [name="subject"]', subject);
@@ -41,15 +43,15 @@ module.exports  = function (userdata, subject, data, pin) {
        within({ frame: '.io-ox-mail-compose-window .editor iframe' }, async () => {
            I.fillField('.mce-content-body', data);
        });
-   
+
        // Verify icon is next to recipient names
        this.waitForVisible('i.fa-male', 10);
        this.moveCursorTo('i.fa-male', 2, 2);
        //this.waitForVisible('.tooltip');
        //this.see('guest', '.tooltip');
-   
+
        // Send
-       this.click('Send Encrypted');
+       this.click('Send');
 
        // Add guest message
        this.waitForVisible('#message');
@@ -57,12 +59,12 @@ module.exports  = function (userdata, subject, data, pin) {
        this.fillField('.og_guest_message', 'Test introduction text');
 
        this.click('OK');
-       
+
        if (!pin) {  // Additional handling required for pin
         this.waitForVisible('.io-ox-mail-window .leftside');
         I.wait(1);
         I.waitForInvisible('.mail-progress');
        }
 
-   
-};
\ No newline at end of file
+
+};
