@@ -1,16 +1,16 @@
 var allTestFiles = [];
 var TEST_REGEXP = /_spec\.js$/i;
 
-var pathToModule = function(path) {
-  return path;
+var pathToModule = function (path) {
+    return path;
 //   return path.replace(/^\/base\//, '').replace(/\.js$/, '');
 };
 
-Object.keys(window.__karma__.files).forEach(function(file) {
-  if (TEST_REGEXP.test(file)) {
-    // Normalize paths to RequireJS module names.
-    allTestFiles.push(pathToModule(file));
-  }
+Object.keys(window.__karma__.files).forEach(function (file) {
+    if (TEST_REGEXP.test(file)) {
+        // Normalize paths to RequireJS module names.
+        allTestFiles.push(pathToModule(file));
+    }
 });
 localStorage.clear();
 window.oxguarddata = { productName: 'Guard' };
@@ -24,7 +24,7 @@ require(['io.ox/core/extPatterns/stage'], function (Stage) {
     new Stage('io.ox/core/stages', {
         id: 'run_tests',
         index: 99999,
-        run: function (baton) {
+        run: function () {
             requirejs.config({
                 // Karma serves files from '/base/apps'
                 baseUrl: '/base/apps',
